@@ -1,7 +1,7 @@
 package IPC::Run::Patch::Setuid;
 
 our $DATE = '2019-04-30'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -24,14 +24,27 @@ my $p_do_kid_and_exit = sub {
         if ($config{-egid} =~ /\A[0-9]+\z/) {
             # a single number, let's set groups to only this group
             my $groups = $); my $num_groups = 1; $num_groups++ while $groups =~ / /g;
-            $) = join(" ", ($config{-egid}) x $num_groups);
-        } else {
+            my $target = join(" ", ($config{-egid}) x $num_groups);
+            $) = $target;
+            die "Failed setting \$) to '$target'" unless $) eq $target;
+        } elsif ($config{-egid} =~ /\A[0-9]+( [0-9]+)+\z/) {
             $) = $config{-egid};
+            die "Failed setting \$) to '$config{-egid}'"
+                unless $) eq $config{-egid};
+        } else {
+            die "Invalid -egid '$config{-egid}', must be integer or ".
+                "integers separated by space";
         }
     }
 
     log_trace "Setting EUID to $config{-euid} ...";
-    $> = $config{-euid};
+    if ($config{-euid} =~ /\A[0-9]+\z/) {
+        $> = $config{-euid};
+        die "Failed setting \$> to '$config{-euid}'"
+            unless $> eq $config{-euid};
+    } else {
+        die "Invalid -euid, must be integer";
+    }
 
     $ctx->{orig}->(@_);
 };
@@ -74,7 +87,7 @@ IPC::Run::Patch::Setuid - Set EUID
 
 =head1 VERSION
 
-This document describes version 0.002 of IPC::Run::Patch::Setuid (from Perl distribution IPC-Run-Patch-Setuid), released on 2019-04-30.
+This document describes version 0.003 of IPC::Run::Patch::Setuid (from Perl distribution IPC-Run-Patch-Setuid), released on 2019-04-30.
 
 =head1 SYNOPSIS
 
@@ -91,6 +104,10 @@ forking.
 
 Unsigned integer.
 
+=head2 -egid
+
+String. Either a single GID or multiple GID separated by space.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/IPC-Run-Patch-Setuid>.
